version

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package version holds the build version metadata for the wlog binary. Commit and Date are injected at build time via -ldflags.

Index

Constants

This section is empty.

Variables

var Commit string

Commit is the git commit hash, injected at build time via ldflags.

var Date string

Date is the build timestamp, injected at build time via ldflags.

var Version = "0.1.0-dev"

Version is the semantic version of the build. Overridable via ldflags.

Functions

func Short

func Short() string

Short returns just the version token (e.g. "v0.1.0-dev") for compact startup banners per DESIGN 6.

func String

func String() string

String returns a human-readable one-line version description including the commit and build date when they have been injected.

Types

This section is empty.

Jump to